==> jc-1.4.0.tar.gz: gnu/classpath/VMStackWalker.h <==
// public final class gnu.classpath.VMStackWalker

// class file dependencies
// @dep_class a22ea65376bbc9d9 gnu_classpath_VMStackWalker
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_classpath_VMStackWalker_H_
#define _JC_gnu_classpath_VMStackWalker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;

// Typedefs
typedef struct _jc_gnu_classpath_VMStackWalker$sub_refs	_jc_gnu_classpath_VMStackWalker$sub_refs;
typedef struct _jc_gnu_classpath_VMStackWalker$sub_nonrefs	_jc_gnu_classpath_VMStackWalker$sub_nonrefs;
typedef struct _jc_gnu_classpath_VMStackWalker$refs	_jc_gnu_classpath_VMStackWalker$refs;
typedef struct _jc_gnu_classpath_VMStackWalker$nonrefs	_jc_gnu_classpath_VMStackWalker$nonrefs;
typedef struct _jc_gnu_classpath_VMStackWalker$object	_jc_gnu_classpath_VMStackWalker$object;

typedef const struct _jc_gnu_classpath_VMStackWalker$vmethods	_jc_gnu_classpath_VMStackWalker$vmethods;
typedef const struct _jc_gnu_classpath_VMStackWalker$vtable	_jc_gnu_classpath_VMStackWalker$vtable;
typedef const struct _jc_gnu_classpath_VMStackWalker$vtype	_jc_gnu_classpath_VMStackWalker$vtype;

// Constructors
extern void _jc_gnu_classpath_VMStackWalker$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_classpath_VMStackWalker$object *);

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_classpath_VMStackWalker$method$getCallingClass$5954152cf8403ee7(_jc_env *);
extern struct _jc_java_lang_ClassLoader$object *_jc_gnu_classpath_VMStackWalker$method$getCallingClassLoader$620c5621c54f1125(_jc_env *);
extern _jc_object_array *_jc_gnu_classpath_VMStackWalker$method$getClassContext$90ec17340749d24e(_jc_env *);

// Virtual methods structure
struct _jc_gnu_classpath_VMStackWalker$vmethods {
};

// Vtable
struct _jc_gnu_classpath_VMStackWalker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_classpath_VMStackWalker$vmethods	gnu_classpath_VMStackWalker;
};

// Vtype
struct _jc_gnu_classpath_VMStackWalker$vtype {
	_jc_type			type;
	_jc_gnu_classpath_VMStackWalker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_classpath_VMStackWalker$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_classpath_VMStackWalker$refs {
    _jc_gnu_classpath_VMStackWalker$sub_refs	gnu_classpath_VMStackWalker;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_classpath_VMStackWalker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_classpath_VMStackWalker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_classpath_VMStackWalker$sub_nonrefs	gnu_classpath_VMStackWalker;
};

// Object instance structure
struct _jc_gnu_classpath_VMStackWalker$object {
	_jc_gnu_classpath_VMStackWalker$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_classpath_VMStackWalker$vtype	*vtype;
	_jc_gnu_classpath_VMStackWalker$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_classpath_VMStackWalker$vtype _jc_gnu_classpath_VMStackWalker$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_classpath_VMStackWalker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_classpath_VMStackWalker$class_object;

#endif	/* _JC_gnu_classpath_VMStackWalker_H_ */

==> jc-1.4.6.tar.gz: gnu/classpath/VMStackWalker.h <==
// public final class gnu.classpath.VMStackWalker

// class file dependencies
// @dep_class a22ea65376bbc9d9 gnu_classpath_VMStackWalker
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_classpath_VMStackWalker_H_
#define _JC_gnu_classpath_VMStackWalker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;

// Typedefs
typedef struct _jc_gnu_classpath_VMStackWalker$sub_refs	_jc_gnu_classpath_VMStackWalker$sub_refs;
typedef struct _jc_gnu_classpath_VMStackWalker$sub_nonrefs	_jc_gnu_classpath_VMStackWalker$sub_nonrefs;
typedef struct _jc_gnu_classpath_VMStackWalker$refs	_jc_gnu_classpath_VMStackWalker$refs;
typedef struct _jc_gnu_classpath_VMStackWalker$nonrefs	_jc_gnu_classpath_VMStackWalker$nonrefs;
typedef struct _jc_gnu_classpath_VMStackWalker$object	_jc_gnu_classpath_VMStackWalker$object;

typedef const struct _jc_gnu_classpath_VMStackWalker$vmethods	_jc_gnu_classpath_VMStackWalker$vmethods;
typedef const struct _jc_gnu_classpath_VMStackWalker$vtable	_jc_gnu_classpath_VMStackWalker$vtable;
typedef const struct _jc_gnu_classpath_VMStackWalker$vtype	_jc_gnu_classpath_VMStackWalker$vtype;

// Constructors
extern void _jc_gnu_classpath_VMStackWalker$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_classpath_VMStackWalker$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_classpath_VMStackWalker$method$getCallingClass$5954152cf8403ee7(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_ClassLoader$object *_jc_gnu_classpath_VMStackWalker$method$getCallingClassLoader$620c5621c54f1125(_jc_env *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_gnu_classpath_VMStackWalker$method$getClassContext$90ec17340749d24e(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_classpath_VMStackWalker$vmethods {
};

// Vtable
struct _jc_gnu_classpath_VMStackWalker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_classpath_VMStackWalker$vmethods	gnu_classpath_VMStackWalker;
};

// Vtype
struct _jc_gnu_classpath_VMStackWalker$vtype {
	_jc_type			type;
	_jc_gnu_classpath_VMStackWalker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_classpath_VMStackWalker$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_classpath_VMStackWalker$refs {
    _jc_gnu_classpath_VMStackWalker$sub_refs	gnu_classpath_VMStackWalker;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_classpath_VMStackWalker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_classpath_VMStackWalker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_classpath_VMStackWalker$sub_nonrefs	gnu_classpath_VMStackWalker;
};

// Object instance structure
struct _jc_gnu_classpath_VMStackWalker$object {
	_jc_gnu_classpath_VMStackWalker$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_classpath_VMStackWalker$vtype	*vtype;
	_jc_gnu_classpath_VMStackWalker$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_classpath_VMStackWalker$vtype _jc_gnu_classpath_VMStackWalker$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_classpath_VMStackWalker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_classpath_VMStackWalker$class_object;

#endif	/* _JC_gnu_classpath_VMStackWalker_H_ */
